==> fap-0.9.2.tar.bz2: fap-0.9.2/src/audio/converter/converterBackend.cpp <==
/*
 *  Copyright (C) 2009-2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "converterBackend.h"

resamplerBackend::resamplerBackend(const unsigned int srIn, const unsigned int srOut, const size_t frames,
	const unsigned int channels, const unsigned int precision) :
	_channels(channels),
	_sampleSize(precision*channels),
	_data(0) {

	FXTRACE((10, "Conversion ratio %f\n", (float)srIn/srOut));
	FXTRACE((10, "Sample size %d\n", _sampleSize));

	_rate=(((FXuint)srIn)<<16)/srOut;
	FXTRACE((10, "_rate %d\n", _rate));

	FXulong tmp=((FXulong)frames*(FXulong)_rate);
	if (tmp&0xFFFFll)
		tmp+=0x10000ll;

	_bufsize=(tmp>>16)*_sampleSize;
	FXTRACE((10, "input size: %d; output size %d\n", frames, _bufsize/_sampleSize));
	_buffer=new char[_bufsize];
}

resamplerBackend::~resamplerBackend() {

	delete [] _buffer;
}

/******************************************************************************/

converterBackend::converterBackend(const size_t frames, const unsigned int channels, const unsigned int precision) :
	_channels(channels),
	_sampleSize(precision*channels) {

	FXTRACE((10, "Sample size %d\n", _sampleSize));

	_bufsize=frames*_sampleSize;
	FXTRACE((10, "input size: %d; output size %d\n", frames, _bufsize/_sampleSize));
	_buffer=new char[_bufsize];
}

converterBackend::~converterBackend() {

	delete [] _buffer;
}

==> fap-0.11.1.tar.bz2: fap-0.11.1/src/audio/converter/converterBackend.cpp <==
/*
 *  Copyright (C) 2009-2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "converterBackend.h"

#include <fx.h>

resamplerBackend::resamplerBackend(const unsigned int srIn, const unsigned int srOut, const size_t frames,
	const unsigned int channels, const unsigned int precision) :
	_channels(channels),
	_sampleSize(precision*channels),
	_data(0) {

	FXTRACE((10, "Conversion ratio %f\n", (float)srIn/srOut));
	FXTRACE((10, "Sample size %d\n", _sampleSize));

	_rate=(((unsigned int)srIn)<<16)/srOut;
	FXTRACE((10, "_rate %d\n", _rate));

	FXulong tmp=((FXulong)frames*(FXulong)_rate);
	if (tmp&0xFFFFll)
		tmp+=0x10000ll;

	_bufsize=(tmp>>16)*_sampleSize;
	FXTRACE((10, "input size: %d; output size %d\n", static_cast<int>(frames), static_cast<int>(_bufsize/_sampleSize)));
	_buffer=new char[_bufsize];
}

resamplerBackend::~resamplerBackend() {

	delete [] _buffer;
}

/******************************************************************************/

converterBackend::converterBackend(const size_t frames, const unsigned int channels, const unsigned int precision) :
	_channels(channels),
	_sampleSize(precision*channels) {

	FXTRACE((10, "Sample size %d\n", _sampleSize));

	_bufsize=frames*_sampleSize;
	FXTRACE((10, "input size: %d; output size %d\n", static_cast<int>(frames), static_cast<int>(_bufsize/_sampleSize)));
	_buffer=new char[_bufsize];
}

converterBackend::~converterBackend() {

	delete [] _buffer;
}
